camelot.camelot.view.mainwindow.MainWindow

Package camelot :: Package camelot :: Package view :: Module mainwindow :: Class MainWindow |
[hide private]
[frames] | no frames]

# Class MainWindow

source code

Instance Methods | [hide private]
__init__(self, app_admin, parent=None) | source code
about(self) | source code
readSettings(self) | source code
writeSettings(self) | source code
runAction(self, name, callable) | source code
createActions(self) | source code
save(self) | source code
saveAs(self) | source code
cut(self) | source code
copy(self) | source code
paste(self) | source code
printDoc(self) | source code
previewDoc(self) | source code
new(self) | source code
delete(self) | source code
pageSetup(self) | source code
viewFirst(self) selects view's first row | source code
viewLast(self) selects view's last row | source code
viewNext(self) selects view's next row | source code
viewPrevious(self) selects view's previous row | source code
exportToExcel(self) creates an excel file from the view | source code
exportToWord(self) Use windows COM to export the active child window to MS word, by using its toHtml function | source code
exportToMail(self) | source code
createMenus(self) | source code
resizeEvent(self, event) Needed to correctly position the throbber | source code
updateMenus(self) | source code
updateWindowMenu(self) | source code
createToolBars(self) | source code
createNavigationPane(self) | source code
createMdiChild(self, item) | source code
activeMdiChild(self) | source code
createStatusBar(self) | source code
closeEvent(self, event) | source code